#[non_exhaustive]pub struct KeyPage {
pub keys: Vec<String>,
pub next: Option<String>,
}Expand description
Re-exports every public item from klieo-core.
One page of bucket keys plus an opaque cursor for the next page.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.keys: Vec<String>Keys in this page, ascending. Empty iff no key sorts at or after the requested cursor.
next: Option<String>Cursor to pass as the next call’s cursor; None once the final key
has been returned.
Implementations